@@ -1,18 +1,18 @@
 /*
  *      menu-cached.c
- *      
+ *
  *      Copyright 2008 PCMan <pcman.tw@gmail.com>
- *      
+ *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
  *      the Free Software Foundation; either version 2 of the License, or
  *      (at your option) any later version.
- *      
+ *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
  *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *      GNU General Public License for more details.
- *      
+ *
  *      You should have received a copy of the GNU General Public License
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
@@ -36,6 +36,7 @@
 #include <sys/fcntl.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <string.h>
 #include <errno.h>
 #include <signal.h>
 #include <utime.h>
@@ -172,7 +173,7 @@ static gboolean regenerate_cache( const char* menu_name,
     int n_files, status = 0;
     char** files;
     const char* const * argv[] = {
-        BINDIR "/menu-cache-gen",
+        MENUCACHE_LIBEXECDIR "/menu-cache-gen",
         "-l", NULL,
         "-i", NULL,
         "-o", NULL,
@@ -495,7 +496,7 @@ static int create_socket()
     memset(&addr, 0, sizeof(addr));
     addr.sun_family = AF_UNIX;
     get_socket_name( addr.sun_path, sizeof( addr.sun_path ) );
-    
+
     /* remove previous socket file */
     if (unlink(addr.sun_path) < 0) {
 	if (errno != ENOENT)
@@ -504,7 +505,7 @@ static int create_socket()
     /* remove of previous socket file successful */
     else
 	g_warning("removed previous socket file %s");
-    
+
     if(bind(fd, (struct sockaddr *) &addr, sizeof(addr)) < 0)
     {
         g_debug("Failed to bind to socket");
@@ -742,7 +743,7 @@ int main(int argc, char** argv)
     }
     else if (pid != 0) {
 	/* exit parent */
-	exit(0);		
+	exit(0);
     }
 
     /* child (daemon process) != process group leader continues and
@@ -756,13 +757,13 @@ int main(int argc, char** argv)
     }
 
     open_max = sysconf (_SC_OPEN_MAX);
-    for (i = 0; i < open_max; i++) 
+    for (i = 0; i < open_max; i++)
     {
 	/* don't hold open fd opened besides server socket */
 	if (i != fd)
 	    fcntl (i, F_SETFD, FD_CLOEXEC);
     }
-    
+
     /* /dev/null for stdin, stdout, stderr */
     fd = open ("/dev/null", O_RDONLY);
     if (fd != -1)
